# Estatistica no R - Aula 3 (Teste T e ANOVA)
# Luis Anunciacao (Psicometria, PUC-Rio/University of Oregon)
# luisfca@gmail.com www.anovabr.com

library("tidyverse") #carregar pacote
library("effsize")
#Verificar medias
dados_brasil %>% 
  group_by(mulheres) %>% 
  summarise_at(vars(bsq_soma),funs(mean, sd))

ggplot(dados_brasil, aes(x=as.factor(mulheres), y=bsq_soma, fill=as.factor(mulheres))) +
  geom_boxplot() + labs(title="Resultado do BSQ em funo do sexo", x="Sexo", fill="Mulheres?")

#Teste T
#Ambiente R-Base
t.test(bsq_soma ~ mulheres, alternative = c("two.sided"), data=dados_brasil)

#Tamanho do efeito 
cohen.d(bsq_soma ~ factor(mulheres), data=dados_brasil)

#ANOVA
#adicionar classificao do imc
dados_brasil <- dados_brasil %>% 
  mutate(imc_classificacao = if_else(imc < 18.5,"Abaixo",
        if_else(imc >= 18.5 & imc <= 24.9, "Normal","Acima")))
#Realizar ANOVA (one way, 1 VI)
aov(bsq_soma ~ imc_classificacao, data=dados_brasil) %>% summary()
pairwise.t.test(dados_brasil$bsq_soma,dados_brasil$imc_classificacao, p.adj = "bonf") #ajuste bonferroni
pairwise.t.test(dados_brasil$bsq_soma,dados_brasil$imc_classificacao, p.adj = "none") #sem ajuste

dados_brasil %>% 
  filter(!is.na(imc_classificacao)) %>% 
  ggplot(., aes(x=imc_classificacao, y=bsq_soma)) + geom_boxplot()

# Luis Anunciacao, 2017
# This work is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. 
#https://creativecommons.org/licenses/by-nc-sa/4.0/
